Serial package for trio
=======================
This project is an adaption of the `pyserial <https://github.com/pyserial/pyserial/>`__ project
for `trio <https://github.com/python-trio/trio>`__.

Installation
------------
.. code-block:: console

    $ pip install trio-serial

Documentation
-------------
https://trio-serial.1e8.de/
